pub enum ErrorKind {
Unknown,
NetworkError,
ErrorResponse {
status_code: u16,
},
InvalidData,
}Expand description
Classifies why a data source is interrupted or has failed.
Variants
Unknown
The cause is not one of the more specific kinds.
NetworkError
The request failed at the network layer.
ErrorResponse
The server returned an error status code.
InvalidData
The response could not be parsed.