Synchronizer

Trait Synchronizer 

pub trait Synchronizer: Send {
    // Required methods
    fn next(&mut self, selector: Selector) -> FDv2SourceEventFuture<'_>;
    fn name(&self) -> &str;
}
A data source that keeps flag data up to date.

Required Methods

fn next(&mut self, selector: Selector) -> FDv2SourceEventFuture<'_>

Fetches the next batch of changes after the given selector.

fn name(&self) -> &str

The name used in logs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors