pub struct Config { /* private fields */ }Expand description
Immutable configuration object for crate::Client.
Config instances can be created using a ConfigBuilder.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn service_endpoints_builder(&self) -> &ServiceEndpointsBuilder
pub fn service_endpoints_builder(&self) -> &ServiceEndpointsBuilder
Returns the ServiceEndpointsBuilder
Sourcepub fn data_store_builder(&self) -> &dyn DataStoreFactory
pub fn data_store_builder(&self) -> &dyn DataStoreFactory
Returns the DataStoreFactory
Sourcepub fn data_source_builder(&self) -> &dyn DataSourceFactory
pub fn data_source_builder(&self) -> &dyn DataSourceFactory
Returns the DataSourceFactory
Sourcepub fn event_processor_builder(&self) -> &dyn EventProcessorFactory
pub fn event_processor_builder(&self) -> &dyn EventProcessorFactory
Returns the EventProcessorFactory
Sourcepub fn daemon_mode(&self) -> bool
pub fn daemon_mode(&self) -> bool
Returns the daemon mode status
Sourcepub fn application_tag(&self) -> &Option<String>
pub fn application_tag(&self) -> &Option<String>
Returns the tag builder if provided
Sourcepub fn instance_id(&self) -> &str
pub fn instance_id(&self) -> &str
Returns the per-SDK-instance identifier. This is a v4 UUID, generated once when the
Config is built, that is included in the X-LaunchDarkly-Instance-Id HTTP header
on outbound requests for the lifetime of the SDK instance.