pub struct FDv2StreamingBuilder<T: HttpTransport = HyperTransport> { /* private fields */ }Expand description
Configures an FDv2 streaming source, which can only act as a synchronizer.
Implementations
Sourceimpl<T: HttpTransport + Clone + Send + Sync + 'static> FDv2StreamingBuilder<T>
impl<T: HttpTransport + Clone + Send + Sync + 'static> FDv2StreamingBuilder<T>
Sourcepub fn initial_reconnect_delay(&mut self, duration: Duration) -> &mut Self
pub fn initial_reconnect_delay(&mut self, duration: Duration) -> &mut Self
Sets the initial reconnect delay for the streaming connection.
Examples
let mut source = FDv2StreamingBuilder::<HyperTransport>::new();
source.initial_reconnect_delay(Duration::from_secs(10));Trait Implementations
Sourceimpl<T: Clone + HttpTransport> Clone for FDv2StreamingBuilder<T>
impl<T: Clone + HttpTransport> Clone for FDv2StreamingBuilder<T>
Sourcefn clone(&self) -> FDv2StreamingBuilder<T>
fn clone(&self) -> FDv2StreamingBuilder<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: HttpTransport + Clone + Send + Sync + 'static> Default for FDv2StreamingBuilder<T>
impl<T: HttpTransport + Clone + Send + Sync + 'static> Default for FDv2StreamingBuilder<T>
Sourceimpl<T: HttpTransport + Clone + Send + Sync + 'static> FDv2SynchronizerConfig for FDv2StreamingBuilder<T>
impl<T: HttpTransport + Clone + Send + Sync + 'static> FDv2SynchronizerConfig for FDv2StreamingBuilder<T>
Sourcefn build_synchronizer(
&self,
context: &DataSourceBuildContext<'_>,
) -> Result<Box<dyn SynchronizerFactory>, BuildError>
fn build_synchronizer( &self, context: &DataSourceBuildContext<'_>, ) -> Result<Box<dyn SynchronizerFactory>, BuildError>
Builds a synchronizer factory from this configuration.
Sourcefn to_owned(&self) -> Box<dyn FDv2SynchronizerConfig>
fn to_owned(&self) -> Box<dyn FDv2SynchronizerConfig>
Clones this configuration into a new box.