pub trait Synchronizer: Send {
// Required methods
fn next(&mut self, selector: Selector) -> FDv2SourceEventFuture<'_>;
fn name(&self) -> &str;
}Expand description
A data source that keeps flag data up to date.
Required Methods
Sourcefn next(&mut self, selector: Selector) -> FDv2SourceEventFuture<'_>
fn next(&mut self, selector: Selector) -> FDv2SourceEventFuture<'_>
Fetches the next batch of changes after the given selector.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".